From ab7595e92efe12e8f73df7a514d0e54c218e7eed Mon Sep 17 00:00:00 2001
From: Oved Ourfali <oourfali@redhat.com>
Date: Wed, 21 Nov 2012 12:57:19 +0200
Subject: [PATCH] fixes #1961 Adding JSONP support

When using cross-domain requests, it is impossible to read the response
data, and process it.
Using JSONP allows a client, from a specific domain (for example
/domain1), to query data in another doamin (/domain2), and analyze it,
using a callback.

Such a request would be followed by "callback=" parameter. For example:
http://foreman-server:3000/statistics?format=json&callback=analyzeStats

And the response would be:
analyzeStats({"statistics":{"mem_totfree":0.0,"arch_count":{},
"env_count":{},"cpu_count":{},"mem_size":0,"swap_size":0,
"model_count":{},"mem_free":0,"swap_free":0,"klass_count":{},
"os_count":{},"mem_totsize":0.0}})

which will call the analyzeStats callback.
Whereas a regular request,
http://foreman-server:3000/statistics?format=json, will just contain the
JSON data.

More reading on JSONP:
JSONP - http://en.wikipedia.org/wiki/JSONP
JSONP Ruby impl -
www.simb.net/2012/02/06/ruby-and-jsonp
https://github.com/crohr/rack-jsonp/
---
 bundler.d/jsonp.rb           |    3 +++
 config/application.rb        |    5 +++++
 config/boot.rb               |    7 +++++++
 config/settings.yaml.example |    1 +
 4 files changed, 16 insertions(+), 0 deletions(-)
 create mode 100644 bundler.d/jsonp.rb

diff --git a/bundler.d/jsonp.rb b/bundler.d/jsonp.rb
new file mode 100644
index 0000000..2eb4a7d
--- /dev/null
+++ b/bundler.d/jsonp.rb
@@ -0,0 +1,3 @@
+group :jsonp do
+  gem 'rack-jsonp', :require => 'rack/jsonp'
+end
diff --git a/config/application.rb b/config/application.rb
index b744354..2bb43b6 100644
--- a/config/application.rb
+++ b/config/application.rb
@@ -66,6 +66,11 @@ module Foreman
     # enables in memory cache store with ttl
     #config.cache_store = TimedCachedStore.new
     config.cache_store = :file_store, Rails.root.join("tmp")
+
+    if SETTINGS[:support_jsonp]
+      # enables JSONP support for the Rack middleware
+      config.middleware.use Rack::JSONP
+    end
   end
 
   def self.setup_console
diff --git a/config/boot.rb b/config/boot.rb
index 4890256..a52fc76 100644
--- a/config/boot.rb
+++ b/config/boot.rb
@@ -26,4 +26,11 @@ if File.exists?(ENV['BUNDLE_GEMFILE'])
     warn "Libvirt binding are missing - hypervisor management is disabled"
     SETTINGS[:libvirt] = false
   end
+
+  begin
+    if SETTINGS[:support_jsonp]
+      require 'rack/jsonp'
+    end
+  end
+
 end
diff --git a/config/settings.yaml.example b/config/settings.yaml.example
index d418a6a..f245f9b 100644
--- a/config/settings.yaml.example
+++ b/config/settings.yaml.example
@@ -2,3 +2,4 @@
 :unattended: true
 :login: false
 :require_ssl: false
+:support_jsonp: false
-- 
1.7.1

